<!-- markdownlint-disable -->

<a href="..\..\qtstrap\utils\adapter.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.adapter`






---

<a href="..\..\qtstrap\utils\adapter.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `Adapter`




<a href="..\..\qtstrap\utils\adapter.py#L18"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Adapter.__init__`

```python
__init__(other=None)
```








---

<a href="..\..\qtstrap\utils\adapter.py#L47"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Adapter.adapter`

```python
adapter()
```





---

<a href="..\..\qtstrap\utils\adapter.py#L50"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Adapter.kill`

```python
kill()
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
